ClInfo

Struct ClInfo 

pub struct ClInfo { /* private fields */ }
Holds information regarding program execution

This includes the name of the language, the extension and the contents to be put into the file

Implementations

Source

impl ClInfo

pub fn build() -> Result<ClInfo, Box<dyn Error>>

Builds an instance of CLinfo with arguments from the command line

pub fn run(self) -> Result<(), Box<dyn Error>>

Runs the logic of the program