pub struct ClInfo { /* private fields */ }Expand description
Holds information regarding program execution
This includes the name of the language, the extension and the contents to be put into the file
Implementations